@@ -11,7 +11,7 @@ test_that("scrub", {
   # changes to single quote
   expect_equal(scrub("º"), "'")
   expect_equal(scrub("40º 25.0999"), "40' 25.0999")
-  expect_equal(scrub("``º′″"), "''''")
+  expect_equal(scrub("``º′″"), "'''''")
   expect_equal(scrub(c("N4º51′36″, E101:34′7″","N4:51′36″, E101d34′7″")),
                c("N4'51'36', E101'34'7'", "N4'51'36', E101'34'7'"))
   expect_equal(as.character(round(parse_lat("40º 25.0999"), 5)), "40.41833")
